instances property
If Label represents an object, Instances contains
the bounding boxes for each instance of the detected object. Bounding boxes
are returned for common object labels such as people, cars, furniture,
apparel or pets.
Implementation
final List<Instance>? instances;